import { fullUserAvatarFragment, fullUserFragment } from '../users/queries.js'
import { spaceUpdatePostFragment } from '../posts/queries.js'

export const sdgsQuery = `
  query SDGs {
    sdgs {
      data {
        id
        title
        number
      }
    }
  }
`
export const topicsQuery = `
  query Topics {
    topics {
      data {
        id
        title
        isDiscoverSpacesDefault
        slug
      }
    }
  }
`

export const skillsQuery = `
  query Skills {
    skills {
      data {
        id
        title
        slug
      }
    }
  }
`

const spaceOverviewFragment = `
  fragment SpaceOverview on Space {
    id
    title
    description
    cover
    coverBlurhash
    location
    avatar
    avatarBlurhash
    avatarDefaultColor
    name
    creator {
      id
    }
    members(limit: 3) {
      totalResults
      data {
        user {
          id
          avatar
          avatarBlurhash
          avatarLabel
          avatarDefaultColor
        }
      }
    }
  }
`

export const discoverSpacesQuery = `
  ${spaceOverviewFragment}

  query DiscoverSpaces($topicIds: [UUID], $geolocation: GeoJSON, $skillIds: [UUID], $offset: Int!, $limit: Int!) {
    discoverSpaces(
      topicIds: $topicIds
      geolocation: $geolocation
      skillIds: $skillIds
      offset: $offset
      limit: $limit
    ) {
      topicId
      locationId
      skillId
      spaces {
        totalResults
        data {
          ...SpaceOverview
        }
      }
    }
  }
`

export const spacesQuery = `
  ${spaceOverviewFragment}

  query Spaces($topicSlug: String, $geolocation: GeoJSON, $skillSlugs: [String], $offset: Int!, $limit: Int!) {
    spaces(topicSlug: $topicSlug, geolocation: $geolocation, skillSlugs: $skillSlugs, offset: $offset, limit: $limit) {
      totalResults
      data {
        ...SpaceOverview
      }
    }
  }
`

export const fullSpaceMemberFragment = `
  ${fullUserAvatarFragment}
  fragment FullSpaceMember on SpaceMemberPaged {
    totalResults
    data {
      user {
        ...FullUserAvatar
      }
      isAdministrator
    }
  }
`

export const fullSpaceFragment = `
  ${fullUserAvatarFragment}
  ${fullUserFragment}
  fragment FullSpace on Space {
    id
    title
    description
    contactEmail
    contactPhone
    contactDescription
    created
    creator {
      ...FullUser
    }
    avatar
    avatarBlurhash
    cover
    coverBlurhash
    name
    avatarDefaultColor
    location
    geolocation {
      latitude
      longitude
    }
    connectionStatusToMyself
    links {
      id
      type
      url
      name
    }
    collaborationTools {
      id
      domain
      url
      description
      title
      collectionType
      thumbnail
      thumbnailBlurhash
    }
    tasks {
      id
      name
      description
      slotsAvailable
      slotsTaken
      location
      regularity
      visibility
      locationType
      contactEmail
      contactPhone
      thumbnail
      thumbnailBlurhash
      creator {
        ...FullUserAvatar
      }
      skills {
        id
        title
        slug
      }
    }
    topics {
      id
      title
    }
    sdgs {
      id
      title
      number
    }
    onboarding {
      steps {
        text
      }
    }
  }
`

export const spaceByIdQuery = `
  ${fullSpaceFragment}

  query SpaceById($idOrName: String!) {
    spaceById(idOrName: $idOrName) {
      ...FullSpace
    }
  }
`

export const spacePostsBySpaceIdQuery = `
  ${spaceUpdatePostFragment}
  query SpacePostsBySpaceId($idOrName: String!, $offset: Int!, $limit: Int!, $visibility: VisibilityFilter!) {
    spaceById(idOrName: $idOrName) {
      id
      hasPublicPosts
      hasPrivatePosts
      posts(offset: $offset, limit: $limit, visibility: $visibility) {
        data {
          ...SpaceUpdatePostFragment
        }
      }
    }
  }
`

export const mySpacesQuery = `
  ${spaceOverviewFragment}

  query MySpaces {
    mySpaces {
      section
      type
      spaces {
        totalResults
        data {
          ...SpaceOverview
        }
      }
    }
  }
`
